==> rbmn_0.9-2.tar.gz: rbmn/man/objets.Rd <==
\name{provided objects}
\alias{provided objects}
\alias{rbmn0chain.01}
\alias{rbmn0chain.02}
\alias{rbmn0chain.03}
\alias{rbmn0nbn.01}
\alias{rbmn0nbn.02}
\alias{rbmn0nbn.03}
\alias{rbmn0nbn.04}
\alias{rbmn0nbn.05}
\alias{rbmn0adja.01}
\alias{rbmn0adja.02}
\alias{rbmn0adja.03}
\alias{rbmn0adja.04}
\alias{rbmn0adja.05}
\alias{rbmn0mn.01}
\alias{rbmn0mn.02}
\alias{rbmn0mn.03}
\alias{rbmn0mn.04}
\alias{rbmn0mn.05}
\alias{rbmn0gema.01}
\alias{rbmn0gema.02}
\alias{rbmn0gema.03}
\alias{rbmn0gema.04}
\alias{rbmn0gema.05}
\alias{rbmn0crarc.05}
\title{Some examplifying structures}
\description{

  Small examples of adjacency matrices, /nbn/, /chain/, /gema/ and /mn/ objects.

}

\usage{
       rbmn0chain.01
       rbmn0chain.02
       rbmn0chain.03
       rbmn0nbn.01
       rbmn0nbn.02
       rbmn0nbn.03
       rbmn0nbn.04
       rbmn0adja.01
       rbmn0adja.02
       rbmn0adja.03
       rbmn0adja.04
       rbmn0mn.01
       rbmn0mn.02
       rbmn0mn.03
       rbmn0mn.04
       rbmn0gema.01
       rbmn0gema.02
       rbmn0gema.03
       rbmn0gema.04
}

\details{

  \itemize{
    \item \code{rbmn0chain.\#} objects are chain /nbn/ objects
    \item \code{rbmn0nbn.\#} objects are general /nbn/ objects
    \item \code{rbmn0adja.\#} objects are adjacency matrices
    \item \code{rbmn0mn.\#} objects are /mn/ distributions
    \item \code{rbmn0gema.\#} objects are /gema/ generating matrices
  }

  Every last numbers (\#) refer to the same Gaussian Bayesian networks.
}

\author{ Jean-Baptiste Denis }
\keyword{examples}

==> rbmn_0.9-6.tar.gz: rbmn/man/objets.Rd <==
\name{provided objects}
\alias{provided objects}
\alias{rbmn0chain.01}
\alias{rbmn0chain.02}
\alias{rbmn0chain.03}
\alias{rbmn0nbn.01}
\alias{rbmn0nbn.02}
\alias{rbmn0nbn.03}
\alias{rbmn0nbn.04}
\alias{rbmn0nbn.05}
\alias{rbmn0adja.01}
\alias{rbmn0adja.02}
\alias{rbmn0adja.03}
\alias{rbmn0adja.04}
\alias{rbmn0adja.05}
\alias{rbmn0mn.01}
\alias{rbmn0mn.02}
\alias{rbmn0mn.03}
\alias{rbmn0mn.04}
\alias{rbmn0mn.05}
\alias{rbmn0gema.01}
\alias{rbmn0gema.02}
\alias{rbmn0gema.03}
\alias{rbmn0gema.04}
\alias{rbmn0gema.05}
\alias{rbmn0crarc.05}
\title{Some examplifying structures}
\description{

  Small examples of adjacency matrices, /nbn/, /chain/, /gema/ and /mn/ objects.

}

\usage{
       rbmn0chain.01
       rbmn0chain.02
       rbmn0chain.03
       rbmn0nbn.01
       rbmn0nbn.02
       rbmn0nbn.03
       rbmn0nbn.04
       rbmn0adja.01
       rbmn0adja.02
       rbmn0adja.03
       rbmn0adja.04
       rbmn0mn.01
       rbmn0mn.02
       rbmn0mn.03
       rbmn0mn.04
       rbmn0gema.01
       rbmn0gema.02
       rbmn0gema.03
       rbmn0gema.04
}

\details{

  \itemize{
    \item \code{rbmn0chain.#} objects are chain /nbn/ objects
    \item \code{rbmn0nbn.#} objects are general /nbn/ objects
    \item \code{rbmn0adja.#} objects are adjacency matrices
    \item \code{rbmn0mn.#} objects are /mn/ distributions
    \item \code{rbmn0gema.#} objects are /gema/ generating matrices
  }

  Every last numbers (#) refer to the same Gaussian Bayesian networks.
}

\author{ Jean-Baptiste Denis }
\keyword{examples}
